<?php

namespace Tests\Feature;

use App\Models\Product;
use App\Models\User;
use Hash;
use Laravel\Sanctum\Sanctum;
use Tests\TestCase;

class ProductDetailsTest extends TestCase
{
    public function test_success_access_to_product_details_by_admin()
    {
        $user = User::factory()->create([
            'role' => 'admin',
            'password' => Hash::make('123123123'),
        ]);
        Sanctum::actingAs(
            $user,
            ['*']
        );
        $product = Product::factory()->create();
        $response = $this->get('/nova/resources/products/' . $product->id);
        $user->delete();
        $product->delete();
        $response->assertStatus(200);
    }

    public function test_success_access_to_product_details_by_analyst()
    {
        $user = User::factory()->create([
            'role' => 'analyst',
            'password' => Hash::make('123123123'),
        ]);
        Sanctum::actingAs(
            $user,
            ['*']
        );
        $product = Product::factory()->create();
        $response = $this->get('/nova/resources/products/' . $product->id);
        $user->delete();
        $product->delete();
        $response->assertStatus(200);
    }

    public function test_access_to_product_detail_by_common()
    {
        $user = User::factory()->create([
            'role' => 'common',
            'password' => Hash::make('123123123'),
        ]);
        Sanctum::actingAs(
            $user,
            ['*']
        );
        $product = Product::factory()->create();
        $response = $this->get('/nova/resources/products/' . $product->id);
        $user->delete();
        $product->delete();
        $response->assertStatus(403);
    }

    public function test_access_to_product_detail_by_unauthorized()
    {
        $product = Product::factory()->create();
        $response = $this->get('/nova/resources/products/' . $product->id);
        $product->delete();
        $response->assertStatus(302);
    }
}
